Learn R Programming

medicare (version 0.2.0)

hospiceALPHA: Sample Medicare Hospice Cost Report 2014 data

Description

A dataset containing the alpha data for the first 500 hospices in the Hospice 2014 cost reports. This is raw data, similar to what you'd get on your own with read.csv("hospc_2014_ALPHA.csv", stringsAsFactors = FALSE).

Usage

hospiceALPHA

Arguments

Format

A data frame with 61820 rows and 5 variables:
  • V1The rpt_rec_num, used to link a hospices dataset across the 3 yearly files.
  • V2The wksht_cd, indicating which worksheet the variable comes from.
  • V3The line_num, indicating the line on the worksheet where the variable is found.
  • V4The clmn_num, indicating the column on the worksheet where the variable is found.
  • V5The itm_alphanmrc_itm_txt, indicating the variable's value.