Learn R Programming

medicare (version 0.2.0)

hospiceRPT: Sample Medicare Hospice Cost Report 2014 data

Description

A dataset containing the report data for the first 500 hospices in the Hospice 2014 cost reports. This is raw data, similar to what you'd get on your own with read.csv("hospc_2014_RPT.csv", stringsAsFactors = FALSE).

Usage

hospiceRPT

Arguments

Format

A data frame with 500 rows and 5 variables:
  • V1The rpt_rec_num, used to link a hospices dataset across the 3 yearly files.
  • V2The prvdr_ctrl_type_cd, indicating the ownership structure of the facility.
  • V3The prvdr_num, a 6-character unique ID used to link the facility's information across time and with other Medicare data.
  • V4The npi, a unique provider number assigned under HIPAA, which can also be used to link to other data sources.
  • V5The rpt_stus_cd, the status of the report (initial submission, audited and settled, settled w/o audit, reopened). Facility filings can be revised, so even older years' data might be updated if data is accessed multiple times.
  • V6The fy_bgn_dt, the start date for the fiscal year of filing. Most facilities submit cost reports soon after close of their fiscal year. They can also have multiple entries in a calendar year if they change their fiscal year start and end dates.
  • V7The fy_end_dt, fiscal year end date. Usually 365 days after the start, unless the facility is re-basing its fiscal year system.
  • V8The proc_dt, process date, when the report was processed by CMS.
  • V9The initl_rpt_sw, initial report indicator, not currently actively used.
  • V10The last_rpt_sw, last report indicator, not currently used.
  • V11The trnsmtl_num, the current transmittal number when the report was generated.
  • V12The fi_num, fiscal intermediary number, which denotes which fiscal intermediary processes the facility's filings.
  • V13The adr_vndr_cd, automated desk reviewer vendor code, indicating the vendor for the fiscal intermediary.
  • V14The fi_creat_dt, when the fiscal intermediary processed the submitted report.
  • V15The util_cd, indicating the level of medicare utilization by the facility.
  • V16The npr_dt, the date of notice of program reimbursement.
  • V17The spec_ind, a CMS internal special purposes code.
  • V18The fi_rcpt_dt, the date the cost report was received by the fiscal intermediary.