medicare: medicare: tools for simplifying Medicare data analysis
Description
The medicare package contains useful functions for manipulating
raw Medicare public use files. These sometimes come with SAS read-in code
provided, but more frequently require the analyst to manually recode and
rename variables based on thorough review of the data documentation. This
package focuses mostly on Cost Reports and Provider of Service files, but
more support will be added for other sources in the future.
See Also
For more information on Medicare the the data available, see: