pos2010: Sample Medicare Provider of Service 2010 data for hospices
Description
A sample of Provider of Services data for select hospices in 2010.
This is raw data, similar to what you'd get on your own when reading in a csv.
Format
A data frame with 402 rows and 530 variables