Learn R Programming

medicare (version 0.2.0)

pos_names: Provide pre-extracted names for Provider of Service file, years 2000-2010

Description

Provide pre-extracted names for Provider of Service file, years 2000-2010

Usage

pos_names(year)

Arguments

year
A year in the range 2000-2010

Value

A list of names for the POS dataset in the year specified, in the order that the raw data lists themThis function returns the results of running pos_names_extract on the layout and raw data files for the chosen year. For years 2000-2010, the raw data had unhelpful, generic, sequentially numbered variable names. These can be calculated fresh by calling pos_names_extract on the imported dataframe and its corresponding layout .txt file. Alternately, this function returns the names compiled by that function for years 2000-2010, saving the user a step.

Examples

Run this code

# get the list
pos_names(2005)
pos_names(2010)

Run the code above in your browser using DataLab