Learn R Programming

medicare (version 0.2.0)

price_deflate: Deflate prices within a sector, relative to a base period.

Description

CMS publishes yearly final rules that detail annual price increases across various sectors of healthcare spending. In order to analyze spending increases due to utilization changes, it is frequently useful to "deflate" spending based on a reference period, so that observed changes are not due to inflation.

Usage

price_deflate(current_value, sector, current_year, reference_year = 2007)

Arguments

current_value
The current value that is being deflated to reference-period-equivalent dollars
sector
What sector is being adjusted. Currently supports: ip, op, phys, snf, hh, hospice, part_b_drugs, part_d_drugs, and other
current_year
The current year (2002 - 2014)
reference_year
The base period to standardize to (2002 - 2014).

Value

A float value, current_value / (current year index / reference year index)

Examples

Run this code
# convert $100 in current inpatient spending to year 2000 dollars
price_deflate(100, "ip", 2014, 2005) 

Run the code above in your browser using DataLab