price_deflate: Deflate prices within a sector, relative to a base period.
Description
CMS publishes yearly final rules that detail annual price increases across
various sectors of healthcare spending. In order to analyze spending
increases due to utilization changes, it is frequently useful to "deflate"
spending based on a reference period, so that observed changes are not due to
inflation.